@@ -399,9 +399,9 @@ context 'Document' do
     test 'convert methods on built-in converter are registered by default' do
       doc = document_from_string ''
       assert_equal 'html5', doc.attributes['backend']
-      assert doc.attributes.has_key? 'backend-html5'
+      assert doc.attributes.key? 'backend-html5'
       assert_equal 'html', doc.attributes['basebackend']
-      assert doc.attributes.has_key? 'basebackend-html'
+      assert doc.attributes.key? 'basebackend-html'
       converter = doc.converter
       assert_kind_of Asciidoctor::Converter::Html5Converter, converter
       BUILT_IN_ELEMENTS.each do |element|
@@ -413,9 +413,9 @@ context 'Document' do
       doc = document_from_string '', attributes: { 'backend' => 'docbook5' }
       converter = doc.converter
       assert_equal 'docbook5', doc.attributes['backend']
-      assert doc.attributes.has_key? 'backend-docbook5'
+      assert doc.attributes.key? 'backend-docbook5'
       assert_equal 'docbook', doc.attributes['basebackend']
-      assert doc.attributes.has_key? 'basebackend-docbook'
+      assert doc.attributes.key? 'basebackend-docbook'
       converter = doc.converter
       assert_kind_of Asciidoctor::Converter::DocBook5Converter, converter
       BUILT_IN_ELEMENTS.each do |element|
@@ -2017,7 +2017,7 @@ context 'Document' do
 
   context 'Date time attributes' do
     test 'should compute docyear and docdatetime from docdate and doctime' do
-      doc = Asciidoctor::Document.new [], attributes: {'docdate' => '2015-01-01', 'doctime' => '10:00:00-0700'}
+      doc = Asciidoctor::Document.new [], attributes: { 'docdate' => '2015-01-01', 'doctime' => '10:00:00-0700' }
       assert_equal '2015-01-01', (doc.attr 'docdate')
       assert_equal '2015', (doc.attr 'docyear')
       assert_equal '10:00:00-0700', (doc.attr 'doctime')
@@ -2025,7 +2025,7 @@ context 'Document' do
     end
 
     test 'should allow docdate and doctime to be overridden' do
-      doc = Asciidoctor::Document.new [], input_mtime: ::Time.now, attributes: {'docdate' => '2015-01-01', 'doctime' => '10:00:00-0700'}
+      doc = Asciidoctor::Document.new [], input_mtime: ::Time.now, attributes: { 'docdate' => '2015-01-01', 'doctime' => '10:00:00-0700' }
       assert_equal '2015-01-01', (doc.attr 'docdate')
       assert_equal '2015', (doc.attr 'docyear')
       assert_equal '10:00:00-0700', (doc.attr 'doctime')
@@ -2033,13 +2033,13 @@ context 'Document' do
     end
 
     test 'should compute docdatetime from doctime' do
-      doc = Asciidoctor::Document.new [], attributes: {'doctime' => '10:00:00-0700'}
+      doc = Asciidoctor::Document.new [], attributes: { 'doctime' => '10:00:00-0700' }
       assert_equal '10:00:00-0700', (doc.attr 'doctime')
       assert (doc.attr 'docdatetime').end_with?(' 10:00:00-0700')
     end
 
     test 'should compute docyear from docdate' do
-      doc = Asciidoctor::Document.new [], attributes: {'docdate' => '2015-01-01'}
+      doc = Asciidoctor::Document.new [], attributes: { 'docdate' => '2015-01-01' }
       assert_equal '2015', (doc.attr 'docyear')
       assert (doc.attr 'docdatetime').start_with?('2015-01-01 ')
     end
@@ -2047,7 +2047,7 @@ context 'Document' do
     test 'should allow doctime to be overridden' do
       old_source_date_epoch = ENV.delete 'SOURCE_DATE_EPOCH'
       begin
-        doc = Asciidoctor::Document.new [], input_mtime: ::Time.new(2019, 01, 02, 3, 4, 5, "+06:00"), attributes: {'doctime' => '10:00:00-0700'}
+        doc = Asciidoctor::Document.new [], input_mtime: ::Time.new(2019, 1, 2, 3, 4, 5, "+06:00"), attributes: { 'doctime' => '10:00:00-0700' }
         assert_equal '2019-01-02', (doc.attr 'docdate')
         assert_equal '2019', (doc.attr 'docyear')
         assert_equal '10:00:00-0700', (doc.attr 'doctime')
@@ -2060,7 +2060,7 @@ context 'Document' do
     test 'should allow docdate to be overridden' do
       old_source_date_epoch = ENV.delete 'SOURCE_DATE_EPOCH'
       begin
-        doc = Asciidoctor::Document.new [], input_mtime: ::Time.new(2019, 01, 02, 3, 4, 5, "+06:00"), attributes: {'docdate' => '2015-01-01'}
+        doc = Asciidoctor::Document.new [], input_mtime: ::Time.new(2019, 1, 2, 3, 4, 5, "+06:00"), attributes: { 'docdate' => '2015-01-01' }
         assert_equal '2015-01-01', (doc.attr 'docdate')
         assert_equal '2015', (doc.attr 'docyear')
         assert_equal '2015-01-01 03:04:05 +0600', (doc.attr 'docdatetime')
