@@ -475,6 +475,26 @@ context 'Links' do
     assert_xpath '//a[@href="#tigers"][text() = "About Tigers"]', convert_string(input), 1
   end
 
+  test 'xref should use title of target as link text when no explicit reftext is specified' do
+    input = <<~'EOS'
+    <<tigers>>
+
+    [#tigers]
+    == Tigers
+    EOS
+    assert_xpath '//a[@href="#tigers"][text() = "Tigers"]', convert_string(input), 1
+  end
+
+  test 'xref should use title of target as link text when explicit link text is empty' do
+    input = <<~'EOS'
+    <<tigers,>>
+
+    [#tigers]
+    == Tigers
+    EOS
+    assert_xpath '//a[@href="#tigers"][text() = "Tigers"]', convert_string(input), 1
+  end
+
   test 'xref using angled bracket syntax with quoted label' do
     input = <<~'EOS'
     <<tigers,"About Tigers">>
