@@ -222,6 +222,26 @@ context 'Manpage' do
       assert_equal '\\(co & \\(rg are translated to character references, but not the &.', output.lines.last.chomp
     end
 
+    test 'should replace numeric character reference for plus' do
+      input = <<~EOS.chop
+      #{SAMPLE_MANPAGE_HEADER}
+
+      A {plus} B
+      EOS
+      output = Asciidoctor.convert input, backend: :manpage
+      assert_equal 'A + B', output.lines.last.chomp
+    end
+
+    test 'should replace numeric character reference for degree sign' do
+      input = <<~EOS.chop
+      #{SAMPLE_MANPAGE_HEADER}
+
+      0{deg} is freezing
+      EOS
+      output = Asciidoctor.convert input, backend: :manpage
+      assert_equal '0\(de is freezing', output.lines.last.chomp
+    end
+
     test 'should replace em dashes' do
       input = <<~EOS.chop
       #{SAMPLE_MANPAGE_HEADER}
@@ -235,6 +255,16 @@ context 'Manpage' do
       assert_includes output, 'go\\(emto'
     end
 
+    test 'should replace quotes' do
+      input = <<~EOS.chop
+      #{SAMPLE_MANPAGE_HEADER}
+
+      'command'
+      EOS
+      output = Asciidoctor.convert input, backend: :manpage
+      assert_includes output, '\*(Aqcommand\*(Aq'
+    end
+
     test 'should escape lone period' do
       input = <<~EOS.chop
       #{SAMPLE_MANPAGE_HEADER}
@@ -359,7 +389,7 @@ context 'Manpage' do
 
   context 'Backslash' do
     test 'should not escape spaces for empty manual or source fields' do
-      input = SAMPLE_MANPAGE_HEADER.lines.select {|l| !l.start_with?(':man ') }
+      input = SAMPLE_MANPAGE_HEADER.lines.reject {|l| l.start_with? ':man ' }
       output = Asciidoctor.convert input, backend: :manpage, standalone: true
       assert_match ' Manual: \ \&', output
       assert_match ' Source: \ \&', output
@@ -986,6 +1016,69 @@ context 'Manpage' do
     end
   end
 
+  context 'xrefs' do
+    test 'should populate automatic link text for internal xref' do
+      input = <<~EOS.chop
+      #{SAMPLE_MANPAGE_HEADER}
+
+      You can access this information using the options listed under <<_generic_program_information>>.
+
+      == Options
+
+      === Generic Program Information
+
+      --help:: Output a usage message and exit.
+
+      -V, --version:: Output the version number of grep and exit.
+      EOS
+      output = Asciidoctor.convert input, backend: :manpage, attributes: { 'experimental' => '' }
+      assert_includes output, 'You can access this information using the options listed under Generic Program Information.'
+    end
+
+    test 'should populate automatic link text for each occurrence of internal xref' do
+      input = <<~EOS.chop
+      #{SAMPLE_MANPAGE_HEADER}
+
+      You can access this information using the options listed under <<_generic_program_information>>.
+
+      The options listed in <<_generic_program_information>> should always be used by themselves.
+
+      == Options
+
+      === Generic Program Information
+
+      --help:: Output a usage message and exit.
+
+      -V, --version:: Output the version number of grep and exit.
+      EOS
+      output = Asciidoctor.convert input, backend: :manpage, attributes: { 'experimental' => '' }
+      assert_includes output, 'You can access this information using the options listed under Generic Program Information.'
+      assert_includes output, 'The options listed in Generic Program Information should always be used by themselves.'
+    end
+
+    test 'should uppercase the reftext for level-2 section titles if the reftext matches the secton title' do
+      input = <<~EOS.chop
+      #{SAMPLE_MANPAGE_HEADER}
+
+      If you read nothing else, read the <<_foo_bar>> section.
+
+      === Options
+
+      --foo-bar _foobar_::
+      Puts the foo in your bar.
+      See <<_foo_bar>> section for details.
+
+      == Foo Bar
+
+      Foo goes with bar, not baz.
+      EOS
+
+      output = Asciidoctor.convert input, backend: :manpage, attributes: { 'experimental' => '' }
+      assert_includes output, 'If you read nothing else, read the FOO BAR section.'
+      assert_includes output, 'See FOO BAR section for details.'
+    end
+  end
+
   context 'Footnotes' do
     test 'should generate list of footnotes using numbered list with numbers enclosed in brackets' do
       [true, false].each do |standalone|
