@@ -273,13 +273,13 @@ context 'Path Resolver' do
       assert_equal '/usr/share/assets/stylesheet.css', @resolver.system_path('assets/stylesheet.css', '/usr/share')
     end
 
-    test 'File.dirname preserves UNC path root on Windows' do
+    test 'File.dirname preserves UNC path root on Windows', if: windows? do
       assert_equal File.dirname('\\\\server\\docs\\file.html'), '\\\\server\\docs'
-    end if windows?
+    end
 
-    test 'File.dirname preserves posix-style UNC path root on Windows' do
+    test 'File.dirname preserves posix-style UNC path root on Windows', if: windows? do
       assert_equal File.dirname('//server/docs/file.html'), '//server/docs'
-    end if windows?
+    end
 
     test 'resolves UNC path if start is absolute and target is relative' do
       assert_equal '//QA/c$/users/asciidoctor/assets/stylesheet.css', @resolver.system_path('assets/stylesheet.css', '//QA/c$/users/asciidoctor')
@@ -351,12 +351,12 @@ context 'Path Resolver' do
       assert_equal '../../shared/partials', result
     end
 
-    test 'should return original path if relative path cannot be computed' do
+    test 'should return original path if relative path cannot be computed', if: windows? do
       filename = 'D:/path/to/include/file.txt'
       base_dir = 'C:/docs'
       result = @resolver.relative_path filename, base_dir
       assert_equal 'D:/path/to/include/file.txt', result
-    end if windows?
+    end
 
     test 'should resolve relative path relative to base dir in unsafe mode' do
       base_dir = fixture_path 'base'
