@@ -14,7 +14,7 @@ context 'Tables' do
       cells = [%w(A B C), %w(a b c), %w(1 2 3)]
       doc = document_from_string input, standalone: false
       table = doc.blocks[0]
-      assert 100, table.columns.map {|col| col.attributes['colpcwidth'] }.reduce(:+)
+      assert_equal 100, table.columns.map {|col| col.attributes['colpcwidth'] }.reduce(:+)
       output = doc.convert
       assert_css 'table', output, 1
       assert_css 'table.tableblock.frame-all.grid-all.stretch', output, 1
@@ -1490,7 +1490,7 @@ context 'Tables' do
       result = convert_string_to_embedded input, attributes: { 'sectids' => nil }
       headings = xmlnodes_at_css 'h2', result
       assert_equal 3, headings.size
-      headings.each {|heading| assert_nil (heading.attr :id) }
+      headings.each {|heading| assert_nil heading.attr :id }
     end
 
     test 'showtitle can be enabled in AsciiDoc table cell if unset in parent document' do
@@ -2158,7 +2158,7 @@ context 'Tables' do
       EOS
       doc = document_from_string input, standalone: false
       table = doc.blocks[0]
-      assert 100, table.columns.map {|col| col.attributes['colpcwidth'] }.reduce(:+)
+      assert_equal 100, table.columns.map {|col| col.attributes['colpcwidth'] }.reduce(:+)
       output = doc.convert
       assert_css 'table', output, 1
       assert_css 'table > colgroup > col[style*="width: 14.2857"]', output, 6
